@@ -10,35 +10,31 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import os
-import threading
-import math
-import tempfile
-import shutil
 import hashlib
+import math
+import os
+import shutil
 import string
+import tempfile
+import threading
 
-from tests import unittest
-from tests.integration import BaseTransferManagerIntegTest
-import ibm_botocore.session
-from ibm_botocore.compat import six
 from ibm_botocore.client import Config
 
 import ibm_s3transfer
-
-
-urlopen = six.moves.urllib.request.urlopen
+from tests.integration import BaseTransferManagerIntegTest
 
 
 def assert_files_equal(first, second):
     if os.path.getsize(first) != os.path.getsize(second):
-        raise AssertionError("Files are not equal: %s, %s" % (first, second))
+        raise AssertionError(f"Files are not equal: {first}, {second}")
     first_md5 = md5_checksum(first)
     second_md5 = md5_checksum(second)
     if first_md5 != second_md5:
         raise AssertionError(
-            "Files are not equal: %s(md5=%s) != %s(md5=%s)" % (
-                first, first_md5, second, second_md5))
+            "Files are not equal: {}(md5={}) != {}(md5={})".format(
+                first, first_md5, second, second_md5
+            )
+        )
 
 
 def md5_checksum(filename):
@@ -55,7 +51,7 @@ def random_bucket_name(prefix='ibm-boto3-transfer', num_chars=10):
     return prefix + ''.join([base[b % len(base)] for b in random_bytes])
 
 
-class FileCreator(object):
+class FileCreator:
     def __init__(self):
         self.rootdir = tempfile.mkdtemp()
 
@@ -109,53 +105,54 @@ class TestS3Transfers(BaseTransferManagerIntegTest):
     """Tests for the high level ibm_s3transfer module."""
 
     def create_s3_transfer(self, config=None):
-        return ibm_s3transfer.S3Transfer(
-            self.client, config=config
-        )
+        return ibm_s3transfer.S3Transfer(self.client, config=config)
 
     def assert_has_public_read_acl(self, response):
         grants = response['Grants']
-        public_read = [g['Grantee'].get('URI', '') for g in grants
-                       if g['Permission'] == 'READ']
+        public_read = [
+            g['Grantee'].get('URI', '')
+            for g in grants
+            if g['Permission'] == 'READ'
+        ]
         self.assertIn('groups/global/AllUsers', public_read[0])
 
     def test_upload_below_threshold(self):
-        config = ibm_s3transfer.TransferConfig(
-            multipart_threshold=2 * 1024 * 1024)
+        config = ibm_s3transfer.TransferConfig(multipart_threshold=2 * 1024 * 1024)
         transfer = self.create_s3_transfer(config)
         filename = self.files.create_file_with_size(
-            'foo.txt', filesize=1024 * 1024)
-        transfer.upload_file(filename, self.bucket_name,
-                             'foo.txt')
+            'foo.txt', filesize=1024 * 1024
+        )
+        transfer.upload_file(filename, self.bucket_name, 'foo.txt')
         self.addCleanup(self.delete_object, 'foo.txt')
 
         self.assertTrue(self.object_exists('foo.txt'))
 
     def test_upload_above_threshold(self):
-        config = ibm_s3transfer.TransferConfig(
-            multipart_threshold=2 * 1024 * 1024)
+        config = ibm_s3transfer.TransferConfig(multipart_threshold=2 * 1024 * 1024)
         transfer = self.create_s3_transfer(config)
         filename = self.files.create_file_with_size(
-            '20mb.txt', filesize=20 * 1024 * 1024)
-        transfer.upload_file(filename, self.bucket_name,
-                             '20mb.txt')
+            '20mb.txt', filesize=20 * 1024 * 1024
+        )
+        transfer.upload_file(filename, self.bucket_name, '20mb.txt')
         self.addCleanup(self.delete_object, '20mb.txt')
         self.assertTrue(self.object_exists('20mb.txt'))
 
     def test_upload_file_above_threshold_with_acl(self):
-        config = ibm_s3transfer.TransferConfig(
-            multipart_threshold=5 * 1024 * 1024)
+        config = ibm_s3transfer.TransferConfig(multipart_threshold=5 * 1024 * 1024)
         transfer = self.create_s3_transfer(config)
         filename = self.files.create_file_with_size(
-            '6mb.txt', filesize=6 * 1024 * 1024)
+            '6mb.txt', filesize=6 * 1024 * 1024
+        )
         extra_args = {'ACL': 'public-read'}
-        transfer.upload_file(filename, self.bucket_name,
-                             '6mb.txt', extra_args=extra_args)
+        transfer.upload_file(
+            filename, self.bucket_name, '6mb.txt', extra_args=extra_args
+        )
         self.addCleanup(self.delete_object, '6mb.txt')
 
         self.assertTrue(self.object_exists('6mb.txt'))
         response = self.client.get_object_acl(
-            Bucket=self.bucket_name, Key='6mb.txt')
+            Bucket=self.bucket_name, Key='6mb.txt'
+        )
         self.assert_has_public_read_acl(response)
 
     def test_upload_file_above_threshold_with_ssec(self):
@@ -164,21 +161,22 @@ class TestS3Transfers(BaseTransferManagerIntegTest):
             'SSECustomerKey': key_bytes,
             'SSECustomerAlgorithm': 'AES256',
         }
-        config = ibm_s3transfer.TransferConfig(
-            multipart_threshold=5 * 1024 * 1024)
+        config = ibm_s3transfer.TransferConfig(multipart_threshold=5 * 1024 * 1024)
         transfer = self.create_s3_transfer(config)
         filename = self.files.create_file_with_size(
-            '6mb.txt', filesize=6 * 1024 * 1024)
-        transfer.upload_file(filename, self.bucket_name,
-                             '6mb.txt', extra_args=extra_args)
+            '6mb.txt', filesize=6 * 1024 * 1024
+        )
+        transfer.upload_file(
+            filename, self.bucket_name, '6mb.txt', extra_args=extra_args
+        )
         self.addCleanup(self.delete_object, '6mb.txt')
         self.wait_object_exists('6mb.txt', extra_args)
         # A head object will fail if it has a customer key
         # associated with it and it's not provided in the HeadObject
         # request so we can use this to verify our functionality.
         response = self.client.head_object(
-            Bucket=self.bucket_name,
-            Key='6mb.txt', **extra_args)
+            Bucket=self.bucket_name, Key='6mb.txt', **extra_args
+        )
         self.assertEqual(response['SSECustomerAlgorithm'], 'AES256')
 
     def test_progress_callback_on_upload(self):
@@ -191,9 +189,11 @@ class TestS3Transfers(BaseTransferManagerIntegTest):
 
         transfer = self.create_s3_transfer()
         filename = self.files.create_file_with_size(
-            '20mb.txt', filesize=20 * 1024 * 1024)
-        transfer.upload_file(filename, self.bucket_name,
-                             '20mb.txt', callback=progress_callback)
+            '20mb.txt', filesize=20 * 1024 * 1024
+        )
+        transfer.upload_file(
+            filename, self.bucket_name, '20mb.txt', callback=progress_callback
+        )
         self.addCleanup(self.delete_object, '20mb.txt')
 
         # The callback should have been called enough times such that
@@ -213,13 +213,15 @@ class TestS3Transfers(BaseTransferManagerIntegTest):
                 self.amount_seen += amount
 
         client = self.session.create_client(
-            's3', self.region,
-            config=Config(signature_version='s3v4'))
+            's3', self.region, config=Config(signature_version='s3v4')
+        )
         transfer = ibm_s3transfer.S3Transfer(client)
         filename = self.files.create_file_with_size(
-            '10mb.txt', filesize=10 * 1024 * 1024)
-        transfer.upload_file(filename, self.bucket_name,
-                             '10mb.txt', callback=progress_callback)
+            '10mb.txt', filesize=10 * 1024 * 1024
+        )
+        transfer.upload_file(
+            filename, self.bucket_name, '10mb.txt', callback=progress_callback
+        )
         self.addCleanup(self.delete_object, '10mb.txt')
 
         self.assertEqual(self.amount_seen, 10 * 1024 * 1024)
@@ -227,24 +229,27 @@ class TestS3Transfers(BaseTransferManagerIntegTest):
     def test_can_send_extra_params_on_upload(self):
         transfer = self.create_s3_transfer()
         filename = self.files.create_file_with_size('foo.txt', filesize=1024)
-        transfer.upload_file(filename, self.bucket_name,
-                             'foo.txt', extra_args={'ACL': 'public-read'})
+        transfer.upload_file(
+            filename,
+            self.bucket_name,
+            'foo.txt',
+            extra_args={'ACL': 'public-read'},
+        )
         self.addCleanup(self.delete_object, 'foo.txt')
 
         self.wait_object_exists('foo.txt')
         response = self.client.get_object_acl(
-            Bucket=self.bucket_name, Key='foo.txt')
+            Bucket=self.bucket_name, Key='foo.txt'
+        )
         self.assert_has_public_read_acl(response)
 
     def test_can_configure_threshold(self):
-        config = ibm_s3transfer.TransferConfig(
-            multipart_threshold=6 * 1024 * 1024
-        )
+        config = ibm_s3transfer.TransferConfig(multipart_threshold=6 * 1024 * 1024)
         transfer = self.create_s3_transfer(config)
         filename = self.files.create_file_with_size(
-            'foo.txt', filesize=8 * 1024 * 1024)
-        transfer.upload_file(filename, self.bucket_name,
-                             'foo.txt')
+            'foo.txt', filesize=8 * 1024 * 1024
+        )
+        transfer.upload_file(filename, self.bucket_name, 'foo.txt')
         self.addCleanup(self.delete_object, 'foo.txt')
 
         self.assertTrue(self.object_exists('foo.txt'))
@@ -263,8 +268,9 @@ class TestS3Transfers(BaseTransferManagerIntegTest):
         transfer = self.create_s3_transfer()
 
         download_path = os.path.join(self.files.rootdir, 'downloaded.txt')
-        transfer.download_file(self.bucket_name, 'foo.txt',
-                               download_path, extra_args=extra_args)
+        transfer.download_file(
+            self.bucket_name, 'foo.txt', download_path, extra_args=extra_args
+        )
         with open(download_path, 'rb') as f:
             self.assertEqual(f.read(), b'hello world')
 
@@ -278,33 +284,38 @@ class TestS3Transfers(BaseTransferManagerIntegTest):
 
         transfer = self.create_s3_transfer()
         filename = self.files.create_file_with_size(
-            '20mb.txt', filesize=20 * 1024 * 1024)
+            '20mb.txt', filesize=20 * 1024 * 1024
+        )
         self.upload_file(filename, '20mb.txt')
 
         download_path = os.path.join(self.files.rootdir, 'downloaded.txt')
-        transfer.download_file(self.bucket_name, '20mb.txt',
-                               download_path, callback=progress_callback)
+        transfer.download_file(
+            self.bucket_name,
+            '20mb.txt',
+            download_path,
+            callback=progress_callback,
+        )
 
         self.assertEqual(self.amount_seen, 20 * 1024 * 1024)
 
     def test_download_below_threshold(self):
         transfer = self.create_s3_transfer()
         filename = self.files.create_file_with_size(
-            'foo.txt', filesize=1024 * 1024)
+            'foo.txt', filesize=1024 * 1024
+        )
         self.upload_file(filename, 'foo.txt')
 
         download_path = os.path.join(self.files.rootdir, 'downloaded.txt')
-        transfer.download_file(self.bucket_name, 'foo.txt',
-                               download_path)
+        transfer.download_file(self.bucket_name, 'foo.txt', download_path)
         assert_files_equal(filename, download_path)
 
     def test_download_above_threshold(self):
         transfer = self.create_s3_transfer()
         filename = self.files.create_file_with_size(
-            'foo.txt', filesize=20 * 1024 * 1024)
+            'foo.txt', filesize=20 * 1024 * 1024
+        )
         self.upload_file(filename, 'foo.txt')
 
         download_path = os.path.join(self.files.rootdir, 'downloaded.txt')
-        transfer.download_file(self.bucket_name, 'foo.txt',
-                               download_path)
+        transfer.download_file(self.bucket_name, 'foo.txt', download_path)
         assert_files_equal(filename, download_path)
